@@ -19,23 +19,23 @@ pub fn repair_response_packet(
         .get_data_shred(slot, shred_index)
         .expect("Blockstore could not get data shred");
     shred
-        .map(|shred| repair_response_packet_from_shred(shred, dest, nonce))
+        .map(|shred| repair_response_packet_from_bytes(shred, dest, nonce))
         .unwrap_or(None)
 }
 
-pub fn repair_response_packet_from_shred(
-    shred: Vec<u8>,
+pub fn repair_response_packet_from_bytes(
+    bytes: Vec<u8>,
     dest: &SocketAddr,
     nonce: Nonce,
 ) -> Option<Packet> {
     let mut packet = Packet::default();
-    packet.meta.size = shred.len() + SIZE_OF_NONCE;
+    packet.meta.size = bytes.len() + SIZE_OF_NONCE;
     if packet.meta.size > packet.data.len() {
         return None;
     }
     packet.meta.set_addr(dest);
-    packet.data[..shred.len()].copy_from_slice(&shred);
-    let mut wr = io::Cursor::new(&mut packet.data[shred.len()..]);
+    packet.data[..bytes.len()].copy_from_slice(&bytes);
+    let mut wr = io::Cursor::new(&mut packet.data[bytes.len()..]);
     bincode::serialize_into(&mut wr, &nonce).expect("Buffer not large enough to fit nonce");
     Some(packet)
 }
@@ -81,7 +81,7 @@ mod test {
         Shredder::sign_shred(&keypair, &mut shred);
         trace!("signature {}", shred.common_header.signature);
         let nonce = 9;
-        let mut packet = repair_response_packet_from_shred(
+        let mut packet = repair_response_packet_from_bytes(
             shred.payload,
             &SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080),
             nonce,
